DREAM7
==========

DREAM7 had 4 challenges, which we refer to as D7C1, D7C2 and D7C3, D7C4.

For full details see: http://dreamchallenges.org/project-list/dream7-2012/

Click on the image below to jump to the **synapse page** related to each challenge:

  


.. figure:: http://dreamchallenges.org/wordpress2/wp-content/uploads/closed_network_top.jpg
    :target:   https://www.synapse.org/#!Synapse:syn2821735/wiki/ 
    
    **D7C1** - DREAM 7 - Network Topology and Parameter Inference Challenge 



